@@ -22,6 +22,7 @@
 
 #include <glib/gi18n.h>
 
+#include "cc-alt-chars-key-dialog.h"
 #include "cc-keyboard-item.h"
 #include "cc-keyboard-manager.h"
 #include "cc-keyboard-option.h"
@@ -54,10 +55,15 @@ struct _CcKeyboardPanel
   guint               search_bar_handler_id;
 
   /* Shortcuts */
-  GtkWidget          *listbox;
+  GtkWidget          *shortcuts_listbox;
   GtkListBoxRow      *add_shortcut_row;
   GtkSizeGroup       *accelerator_sizegroup;
 
+  /* Alternate characters key */
+  CcAltCharsKeyDialog *alt_chars_key_dialog;
+  GSettings           *input_source_settings;
+  GtkWidget           *value_alternate_chars;
+
   /* Custom shortcut dialog */
   GtkWidget          *shortcut_editor;
 
@@ -78,6 +84,21 @@ static const gchar* custom_css =
 "    padding: 0;"
 "}";
 
+
+#define DEFAULT_LV3_OPTION 5
+static struct {
+  const char *xkb_option;
+  const char *label;
+  const char *widget_name;
+} lv3_xkb_options[] = {
+  { "lv3:switch", NC_("keyboard key", "Right Ctrl"), "radiobutton_rightctrl" },
+  { "lv3:menu_switch", NC_("keyboard key", "Menu Key"), "radiobutton_menukey" },
+  { "lv3:lwin_switch", NC_("keyboard key", "Left Super"), "radiobutton_leftsuper" },
+  { "lv3:rwin_switch", NC_("keyboard key", "Right Super"), "radiobutton_rightsuper" },
+  { "lv3:lalt_switch", NC_("keyboard key", "Left Alt"), "radiobutton_leftalt" },
+  { "lv3:ralt_switch", NC_("keyboard key", "Right Alt"), "radiobutton_rightalt" },
+};
+
 /* RowData functions */
 static RowData *
 row_data_new (CcKeyboardItem *item,
@@ -199,7 +220,7 @@ reset_all_clicked_cb (CcKeyboardPanel *self)
 
   if (response == GTK_RESPONSE_ACCEPT)
     {
-      gtk_container_foreach (GTK_CONTAINER (self->listbox),
+      gtk_container_foreach (GTK_CONTAINER (self->shortcuts_listbox),
                              reset_all_shortcuts_cb,
                              self);
     }
@@ -265,7 +286,7 @@ add_item (CcKeyboardPanel *self,
                                "binding",
                                label,
                               "label",
-                               G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE,
+                               G_SETTINGS_BIND_GET | G_BINDING_SYNC_CREATE,
                                transform_binding_to_accel,
                                NULL, NULL, NULL);
 
@@ -309,7 +330,7 @@ add_item (CcKeyboardPanel *self,
                           row_data_new (item, section_id, section_title),
                           (GDestroyNotify) row_data_free);
 
-  gtk_container_add (GTK_CONTAINER (self->listbox), row);
+  gtk_container_add (GTK_CONTAINER (self->shortcuts_listbox), row);
 }
 
 static void
@@ -318,7 +339,7 @@ remove_item (CcKeyboardPanel *self,
 {
   GList *children, *l;
 
-  children = gtk_container_get_children (GTK_CONTAINER (self->listbox));
+  children = gtk_container_get_children (GTK_CONTAINER (self->shortcuts_listbox));
 
   for (l = children; l != NULL; l = l->next)
     {
@@ -328,7 +349,7 @@ remove_item (CcKeyboardPanel *self,
 
       if (row_data->item == item)
         {
-          gtk_container_remove (GTK_CONTAINER (self->listbox), l->data);
+          gtk_container_remove (GTK_CONTAINER (self->shortcuts_listbox), l->data);
           break;
         }
     }
@@ -599,6 +620,55 @@ shortcut_row_activated (GtkWidget       *button,
   gtk_widget_show (self->shortcut_editor);
 }
 
+static void
+alternate_chars_activated (GtkWidget       *button,
+                           GtkListBoxRow   *row,
+                           CcKeyboardPanel *self)
+{
+  GtkWindow *window;
+
+  window = GTK_WINDOW (cc_shell_get_toplevel (cc_panel_get_shell (CC_PANEL (self))));
+
+  gtk_window_set_transient_for (GTK_WINDOW (self->alt_chars_key_dialog), window);
+  gtk_widget_show (GTK_WIDGET (self->alt_chars_key_dialog));
+}
+
+static gboolean
+transform_binding_to_alt_chars (GValue   *value,
+                                GVariant *variant,
+                                gpointer  user_data)
+{
+  const char **items;
+  guint i;
+
+  items = g_variant_get_strv (variant, NULL);
+  if (!items)
+    goto bail;
+
+  for (i = 0; items[i] != NULL; i++)
+    {
+      guint j;
+
+      if (!g_str_has_prefix (items[i], "lv3:"))
+        continue;
+
+      for (j = 0; j < G_N_ELEMENTS (lv3_xkb_options); j++)
+        {
+          if (!g_str_equal (items[i], lv3_xkb_options[j].xkb_option))
+            continue;
+
+          g_value_set_string (value,
+                              g_dpgettext2 (NULL, "keyboard key", lv3_xkb_options[j].label));
+          return TRUE;
+        }
+    }
+
+bail:
+  g_value_set_string (value,
+                      g_dpgettext2 (NULL, "keyboard key", lv3_xkb_options[DEFAULT_LV3_OPTION].label));
+  return TRUE;
+}
+
 static void
 cc_keyboard_panel_set_property (GObject      *object,
                                guint         property_id,
@@ -629,6 +699,7 @@ cc_keyboard_panel_finalize (GObject *object)
 
   g_clear_pointer (&self->pictures_regex, g_regex_unref);
   g_clear_object (&self->accelerator_sizegroup);
+  g_clear_object (&self->input_source_settings);
 
   cc_keyboard_option_clear_all ();
 
@@ -684,14 +755,16 @@ cc_keyboard_panel_class_init (CcKeyboardPanelClass *klass)
 
   gtk_widget_class_bind_template_child (widget_class, CcKeyboardPanel, add_shortcut_row);
   gtk_widget_class_bind_template_child (widget_class, CcKeyboardPanel, empty_search_placeholder);
-  gtk_widget_class_bind_template_child (widget_class, CcKeyboardPanel, listbox);
   gtk_widget_class_bind_template_child (widget_class, CcKeyboardPanel, reset_button);
   gtk_widget_class_bind_template_child (widget_class, CcKeyboardPanel, search_bar);
   gtk_widget_class_bind_template_child (widget_class, CcKeyboardPanel, search_button);
   gtk_widget_class_bind_template_child (widget_class, CcKeyboardPanel, search_entry);
+  gtk_widget_class_bind_template_child (widget_class, CcKeyboardPanel, shortcuts_listbox);
+  gtk_widget_class_bind_template_child (widget_class, CcKeyboardPanel, value_alternate_chars);
 
   gtk_widget_class_bind_template_callback (widget_class, reset_all_clicked_cb);
   gtk_widget_class_bind_template_callback (widget_class, shortcut_row_activated);
+  gtk_widget_class_bind_template_callback (widget_class, alternate_chars_activated);
 }
 
 static void
@@ -713,6 +786,20 @@ cc_keyboard_panel_init (CcKeyboardPanel *self)
 
   g_object_unref (provider);
 
+  /* Alternate characters key */
+  self->input_source_settings = g_settings_new ("org.gnome.desktop.input-sources");
+  g_settings_bind_with_mapping (self->input_source_settings,
+                                "xkb-options",
+                                self->value_alternate_chars,
+                                "label",
+                                G_SETTINGS_BIND_GET,
+                                transform_binding_to_alt_chars,
+                                NULL,
+                                self->value_alternate_chars,
+                                NULL);
+
+  self->alt_chars_key_dialog = cc_alt_chars_key_dialog_new (self->input_source_settings);
+
   /* Shortcut manager */
   self->manager = cc_keyboard_manager_new ();
 
@@ -734,22 +821,22 @@ cc_keyboard_panel_init (CcKeyboardPanel *self)
   /* Shortcut editor dialog */
   self->shortcut_editor = cc_keyboard_shortcut_editor_new (self->manager);
 
-  /* Setup the shortcuts listbox */
-  gtk_list_box_set_sort_func (GTK_LIST_BOX (self->listbox),
+  /* Setup the shortcuts shortcuts_listbox */
+  gtk_list_box_set_sort_func (GTK_LIST_BOX (self->shortcuts_listbox),
                               sort_function,
                               self,
                               NULL);
 
-  gtk_list_box_set_header_func (GTK_LIST_BOX (self->listbox),
+  gtk_list_box_set_header_func (GTK_LIST_BOX (self->shortcuts_listbox),
                                 header_function,
                                 self,
                                 NULL);
 
-  gtk_list_box_set_filter_func (GTK_LIST_BOX (self->listbox),
+  gtk_list_box_set_filter_func (GTK_LIST_BOX (self->shortcuts_listbox),
                                 filter_function,
                                 self,
                                 NULL);
 
-  gtk_list_box_set_placeholder (GTK_LIST_BOX (self->listbox), self->empty_search_placeholder);
+  gtk_list_box_set_placeholder (GTK_LIST_BOX (self->shortcuts_listbox), self->empty_search_placeholder);
 }
 
