@@ -95,7 +95,7 @@ ppd_names_free (gpointer user_data)
     }
 }
 
-static void set_ppd_cb (gchar *printer_name, gboolean success, gpointer user_data);
+static void set_ppd_cb (const gchar *printer_name, gboolean success, gpointer user_data);
 
 static void
 get_ppd_names_cb (PPDName     **names,
@@ -140,7 +140,7 @@ search_for_drivers (PpDetailsDialog *self)
 }
 
 static void
-set_ppd_cb (gchar    *printer_name,
+set_ppd_cb (const gchar *printer_name,
             gboolean  success,
             gpointer  user_data)
 {
