@@ -43,17 +43,17 @@ ippGetRange (ipp_attribute_t *attr,
 }
 #endif
 
-typedef struct
+struct _PpJob
 {
-  GObject parent;
+  GObject parent_instance;
 
   gint    id;
   gchar  *title;
   gint    state;
   gchar **auth_info_required;
-} PpJobPrivate;
+};
 
-G_DEFINE_TYPE_WITH_PRIVATE (PpJob, pp_job, G_TYPE_OBJECT)
+G_DEFINE_TYPE (PpJob, pp_job, G_TYPE_OBJECT)
 
 enum
 {
@@ -86,14 +86,14 @@ pp_job_cancel_purge_async_dbus_cb (GObject      *source_object,
 }
 
 void
-pp_job_cancel_purge_async (PpJob        *job,
+pp_job_cancel_purge_async (PpJob        *self,
                            gboolean      job_purge)
 {
   GDBusConnection *bus;
   g_autoptr(GError) error = NULL;
   gint            *job_id;
 
-  g_object_get (job, "id", &job_id, NULL);
+  g_object_get (self, "id", &job_id, NULL);
 
   bus = g_bus_get_sync (G_BUS_TYPE_SYSTEM, NULL, &error);
   if (!bus)
@@ -137,14 +137,14 @@ pp_job_set_hold_until_async_dbus_cb (GObject      *source_object,
 }
 
 void
-pp_job_set_hold_until_async (PpJob        *job,
+pp_job_set_hold_until_async (PpJob        *self,
                              const gchar  *job_hold_until)
 {
   GDBusConnection  *bus;
   g_autoptr(GError) error = NULL;
   gint             *job_id;
 
-  g_object_get (job, "id", &job_id, NULL);
+  g_object_get (self, "id", &job_id, NULL);
 
   bus = g_bus_get_sync (G_BUS_TYPE_SYSTEM, NULL, &error);
   if (!bus)
@@ -180,23 +180,21 @@ pp_job_get_property (GObject    *object,
                      GValue     *value,
                      GParamSpec *pspec)
 {
-  PpJobPrivate *priv;
-
-  priv = pp_job_get_instance_private (PP_JOB (object));
+  PpJob *self = PP_JOB (object);
 
   switch (property_id)
     {
       case PROP_ID:
-        g_value_set_int (value, priv->id);
+        g_value_set_int (value, self->id);
         break;
       case PROP_TITLE:
-        g_value_set_string (value, priv->title);
+        g_value_set_string (value, self->title);
         break;
       case PROP_STATE:
-        g_value_set_int (value, priv->state);
+        g_value_set_int (value, self->state);
         break;
       case PROP_AUTH_INFO_REQUIRED:
-        g_value_set_pointer (value, g_strdupv (priv->auth_info_required));
+        g_value_set_pointer (value, g_strdupv (self->auth_info_required));
         break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -210,24 +208,22 @@ pp_job_set_property (GObject      *object,
                      const GValue *value,
                      GParamSpec   *pspec)
 {
-  PpJobPrivate *priv;
-
-  priv = pp_job_get_instance_private (PP_JOB (object));
+  PpJob *self = PP_JOB (object);
 
   switch (property_id)
     {
       case PROP_ID:
-        priv->id = g_value_get_int (value);
+        self->id = g_value_get_int (value);
         break;
       case PROP_TITLE:
-        g_free (priv->title);
-        priv->title = g_value_dup_string (value);
+        g_free (self->title);
+        self->title = g_value_dup_string (value);
         break;
       case PROP_STATE:
-        priv->state = g_value_get_int (value);
+        self->state = g_value_get_int (value);
         break;
       case PROP_AUTH_INFO_REQUIRED:
-        priv->auth_info_required = g_strdupv (g_value_get_pointer (value));
+        self->auth_info_required = g_strdupv (g_value_get_pointer (value));
         break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -238,12 +234,10 @@ pp_job_set_property (GObject      *object,
 static void
 pp_job_finalize (GObject *object)
 {
-  PpJobPrivate *priv;
+  PpJob *self = PP_JOB (object);
 
-  priv = pp_job_get_instance_private (PP_JOB (object));
-
-  g_free (priv->title);
-  g_strfreev (priv->auth_info_required);
+  g_clear_pointer (&self->title, g_free);
+  g_clear_pointer (&self->auth_info_required, g_strfreev);
 
   G_OBJECT_CLASS (pp_job_parent_class)->finalize (object);
 }
@@ -290,19 +284,17 @@ _pp_job_get_attributes_thread (GTask        *task,
                                gpointer      task_data,
                                GCancellable *cancellable)
 {
-  ipp_attribute_t *attr = NULL;
-  GVariantBuilder  builder;
-  GVariant        *attributes = NULL;
-  gchar          **attributes_names = task_data;
-  PpJobPrivate    *priv;
-  ipp_t           *request;
-  ipp_t           *response = NULL;
-  gchar           *job_uri;
-  gint             i, j, length = 0, n_attrs = 0;
+  PpJob *self = PP_JOB (source_object);
+  ipp_attribute_t  *attr = NULL;
+  GVariantBuilder   builder;
+  GVariant         *attributes = NULL;
+  gchar           **attributes_names = task_data;
+  ipp_t            *request;
+  ipp_t            *response = NULL;
+  g_autofree gchar *job_uri = NULL;
+  gint              i, j, length = 0, n_attrs = 0;
 
-  priv = pp_job_get_instance_private (source_object);
-
-  job_uri = g_strdup_printf ("ipp://localhost/jobs/%d", priv->id);
+  job_uri = g_strdup_printf ("ipp://localhost/jobs/%d", self->id);
 
   if (attributes_names != NULL)
     {
@@ -394,13 +386,12 @@ _pp_job_get_attributes_thread (GTask        *task,
 
       attributes = g_variant_builder_end (&builder);
     }
-  g_free (job_uri);
 
   g_task_return_pointer (task, attributes, (GDestroyNotify) g_variant_unref);
 }
 
 void
-pp_job_get_attributes_async (PpJob                *job,
+pp_job_get_attributes_async (PpJob                *self,
                              gchar               **attributes_names,
                              GCancellable         *cancellable,
                              GAsyncReadyCallback   callback,
@@ -408,7 +399,7 @@ pp_job_get_attributes_async (PpJob                *job,
 {
   GTask *task;
 
-  task = g_task_new (job, cancellable, callback, user_data);
+  task = g_task_new (self, cancellable, callback, user_data);
   g_task_set_task_data (task, g_strdupv (attributes_names), (GDestroyNotify) g_strfreev);
   g_task_run_in_thread (task, _pp_job_get_attributes_thread);
 
@@ -416,11 +407,11 @@ pp_job_get_attributes_async (PpJob                *job,
 }
 
 GVariant *
-pp_job_get_attributes_finish (PpJob         *job,
+pp_job_get_attributes_finish (PpJob         *self,
                               GAsyncResult  *result,
                               GError       **error)
 {
-  g_return_val_if_fail (g_task_is_valid (result, job), NULL);
+  g_return_val_if_fail (g_task_is_valid (result, self), NULL);
 
   return g_task_propagate_pointer (G_TASK (result), error);
 }
@@ -431,19 +422,16 @@ _pp_job_authenticate_thread (GTask        *task,
                              gpointer      task_data,
                              GCancellable *cancellable)
 {
-  PpJobPrivate  *priv;
+  PpJob         *self = source_object;
   gboolean       result = FALSE;
   gchar        **auth_info = task_data;
   ipp_t         *request;
   ipp_t         *response = NULL;
-  gchar         *job_uri;
   gint           length;
 
-  priv = pp_job_get_instance_private (source_object);
-
   if (auth_info != NULL)
     {
-      job_uri = g_strdup_printf ("ipp://localhost/jobs/%d", priv->id);
+      g_autofree gchar *job_uri = g_strdup_printf ("ipp://localhost/jobs/%d", self->id);
 
       length = g_strv_length (auth_info);
 
@@ -460,15 +448,13 @@ _pp_job_authenticate_thread (GTask        *task,
 
       if (response != NULL)
         ippDelete (response);
-
-      g_free (job_uri);
     }
 
   g_task_return_boolean (task, result);
 }
 
 void
-pp_job_authenticate_async (PpJob                *job,
+pp_job_authenticate_async (PpJob                *self,
                            gchar               **auth_info,
                            GCancellable         *cancellable,
                            GAsyncReadyCallback   callback,
@@ -476,7 +462,7 @@ pp_job_authenticate_async (PpJob                *job,
 {
   GTask *task;
 
-  task = g_task_new (job, cancellable, callback, user_data);
+  task = g_task_new (self, cancellable, callback, user_data);
   g_task_set_task_data (task, g_strdupv (auth_info), (GDestroyNotify) g_strfreev);
   g_task_run_in_thread (task, _pp_job_authenticate_thread);
 
@@ -484,11 +470,11 @@ pp_job_authenticate_async (PpJob                *job,
 }
 
 gboolean
-pp_job_authenticate_finish (PpJob         *job,
+pp_job_authenticate_finish (PpJob         *self,
                             GAsyncResult  *result,
                             GError       **error)
 {
-  g_return_val_if_fail (g_task_is_valid (result, job), FALSE);
+  g_return_val_if_fail (g_task_is_valid (result, self), FALSE);
 
   return g_task_propagate_boolean (G_TASK (result), error);
 }
