@@ -29,17 +29,16 @@
 #include "pp-ppd-option-widget.h"
 #include "pp-utils.h"
 
-#define PP_PPD_OPTION_WIDGET_GET_PRIVATE(o)  \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((o), PP_TYPE_PPD_OPTION_WIDGET, PpPPDOptionWidgetPrivate))
-
 static void pp_ppd_option_widget_finalize (GObject *object);
 
-static gboolean construct_widget   (PpPPDOptionWidget *widget);
-static void     update_widget      (PpPPDOptionWidget *widget);
-static void     update_widget_real (PpPPDOptionWidget *widget);
+static gboolean construct_widget   (PpPPDOptionWidget *self);
+static void     update_widget      (PpPPDOptionWidget *self);
+static void     update_widget_real (PpPPDOptionWidget *self);
 
-struct PpPPDOptionWidgetPrivate
+struct _PpPPDOptionWidget
 {
+  GtkBox parent_instance;
+
   GtkWidget *switch_button;
   GtkWidget *combo;
   GtkWidget *image;
@@ -140,79 +139,48 @@ pp_ppd_option_widget_class_init (PpPPDOptionWidgetClass *class)
   object_class = G_OBJECT_CLASS (class);
 
   object_class->finalize = pp_ppd_option_widget_finalize;
-
-  g_type_class_add_private (class, sizeof (PpPPDOptionWidgetPrivate));
 }
 
 static void
-pp_ppd_option_widget_init (PpPPDOptionWidget *widget)
+pp_ppd_option_widget_init (PpPPDOptionWidget *self)
 {
-  PpPPDOptionWidgetPrivate *priv;
-
-  gtk_orientable_set_orientation (GTK_ORIENTABLE (widget),
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (self),
                                   GTK_ORIENTATION_HORIZONTAL);
-  priv = widget->priv = PP_PPD_OPTION_WIDGET_GET_PRIVATE (widget);
 
-  priv->switch_button = NULL;
-  priv->combo = NULL;
-  priv->image = NULL;
-  priv->box = NULL;
+  self->switch_button = NULL;
+  self->combo = NULL;
+  self->image = NULL;
+  self->box = NULL;
 
-  priv->printer_name = NULL;
-  priv->option_name = NULL;
+  self->printer_name = NULL;
+  self->option_name = NULL;
 
-  priv->destination = NULL;
-  priv->destination_set = FALSE;
+  self->destination = NULL;
+  self->destination_set = FALSE;
 
-  priv->ppd_filename = NULL;
-  priv->ppd_filename_set = FALSE;
+  self->ppd_filename = NULL;
+  self->ppd_filename_set = FALSE;
 }
 
 static void
 pp_ppd_option_widget_finalize (GObject *object)
 {
-  PpPPDOptionWidget        *widget = PP_PPD_OPTION_WIDGET (object);
-  PpPPDOptionWidgetPrivate *priv = widget->priv;
+  PpPPDOptionWidget *self = PP_PPD_OPTION_WIDGET (object);
 
-  if (priv)
+  g_cancellable_cancel (self->cancellable);
+  if (self->ppd_filename)
+    g_unlink (self->ppd_filename);
+
+  g_clear_pointer (&self->option, cups_option_free);
+  g_clear_pointer (&self->printer_name, g_free);
+  g_clear_pointer (&self->option_name, g_free);
+  if (self->destination)
     {
-      if (priv->option)
-        {
-          cups_option_free (priv->option);
-          priv->option = NULL;
-        }
-
-      if (priv->printer_name)
-        {
-          g_free (priv->printer_name);
-          priv->printer_name = NULL;
-        }
-
-      if (priv->option_name)
-        {
-          g_free (priv->option_name);
-          priv->option_name = NULL;
-        }
-
-      if (priv->destination)
-        {
-          cupsFreeDests (1, priv->destination);
-          priv->destination = NULL;
-        }
-
-      if (priv->ppd_filename)
-        {
-          g_unlink (priv->ppd_filename);
-          g_free (priv->ppd_filename);
-          priv->ppd_filename = NULL;
-        }
-
-      if (priv->cancellable)
-        {
-          g_cancellable_cancel (priv->cancellable);
-          g_object_unref (priv->cancellable);
-        }
+      cupsFreeDests (1, self->destination);
+      self->destination = NULL;
     }
+  g_clear_pointer (&self->ppd_filename, g_free);
+  g_clear_object (&self->cancellable);
 
   G_OBJECT_CLASS (pp_ppd_option_widget_parent_class)->finalize (object);
 }
@@ -237,32 +205,29 @@ GtkWidget *
 pp_ppd_option_widget_new (ppd_option_t *option,
                           const gchar  *printer_name)
 {
-  PpPPDOptionWidgetPrivate *priv;
-  PpPPDOptionWidget        *widget = NULL;
+  PpPPDOptionWidget *self = NULL;
 
   if (option && printer_name)
     {
-      widget = g_object_new (PP_TYPE_PPD_OPTION_WIDGET, NULL);
+      self = g_object_new (PP_TYPE_PPD_OPTION_WIDGET, NULL);
 
-      priv = PP_PPD_OPTION_WIDGET_GET_PRIVATE (widget);
+      self->printer_name = g_strdup (printer_name);
+      self->option = cups_option_copy (option);
+      self->option_name = g_strdup (option->keyword);
 
-      priv->printer_name = g_strdup (printer_name);
-      priv->option = cups_option_copy (option);
-      priv->option_name = g_strdup (option->keyword);
-
-      if (construct_widget (widget))
+      if (construct_widget (self))
         {
-          update_widget_real (widget);
+          update_widget_real (self);
         }
       else
         {
-          g_object_ref_sink (widget);
-          g_object_unref (widget);
-          widget = NULL;
+          g_object_ref_sink (self);
+          g_object_unref (self);
+          self = NULL;
         }
     }
 
-  return (GtkWidget *) widget;
+  return (GtkWidget *) self;
 }
 
 enum {
@@ -323,18 +288,18 @@ set_cb (GtkTreeModel *model,
         GtkTreeIter  *iter,
         gpointer      data)
 {
-  struct ComboSet *set_data = data;
-  gboolean         found;
-  char            *value;
+  struct ComboSet  *set_data = data;
+  g_autofree gchar *value = NULL;
 
   gtk_tree_model_get (model, iter, VALUE_COLUMN, &value, -1);
-  found = (strcmp (value, set_data->value) == 0);
-  g_free (value);
 
-  if (found)
-    gtk_combo_box_set_active_iter (set_data->combo, iter);
+  if (strcmp (value, set_data->value) == 0)
+    {
+      gtk_combo_box_set_active_iter (set_data->combo, iter);
+      return TRUE;
+    }
 
-  return found;
+  return FALSE;
 }
 
 static void
@@ -370,19 +335,17 @@ static void
 printer_add_option_async_cb (gboolean success,
                              gpointer user_data)
 {
-  PpPPDOptionWidget        *widget = (PpPPDOptionWidget *) user_data;
-  PpPPDOptionWidgetPrivate *priv = widget->priv;
+  PpPPDOptionWidget *self = user_data;
 
   update_widget (user_data);
-  g_clear_object (&priv->cancellable);
+  g_clear_object (&self->cancellable);
 }
 
 static void
 switch_changed_cb (GtkWidget         *switch_button,
                    GParamSpec        *pspec,
-                   PpPPDOptionWidget *widget)
+                   PpPPDOptionWidget *self)
 {
-  PpPPDOptionWidgetPrivate  *priv = widget->priv;
   gchar                    **values;
 
   values = g_new0 (gchar *, 2);
@@ -392,106 +355,104 @@ switch_changed_cb (GtkWidget         *switch_button,
   else
     values[0] = g_strdup ("False");
 
-  if (priv->cancellable)
+  if (self->cancellable)
     {
-      g_cancellable_cancel (priv->cancellable);
-      g_object_unref (priv->cancellable);
+      g_cancellable_cancel (self->cancellable);
+      g_object_unref (self->cancellable);
     }
 
-  priv->cancellable = g_cancellable_new ();
-  printer_add_option_async (priv->printer_name,
-                            priv->option_name,
+  self->cancellable = g_cancellable_new ();
+  printer_add_option_async (self->printer_name,
+                            self->option_name,
                             values,
                             FALSE,
-                            priv->cancellable,
+                            self->cancellable,
                             printer_add_option_async_cb,
-                            widget);
+                            self);
 
   g_strfreev (values);
 }
 
 static void
 combo_changed_cb (GtkWidget         *combo,
-                  PpPPDOptionWidget *widget)
+                  PpPPDOptionWidget *self)
 {
-  PpPPDOptionWidgetPrivate  *priv = widget->priv;
   gchar                    **values;
 
   values = g_new0 (gchar *, 2);
   values[0] = combo_box_get (combo);
 
-  if (priv->cancellable)
+  if (self->cancellable)
     {
-      g_cancellable_cancel (priv->cancellable);
-      g_object_unref (priv->cancellable);
+      g_cancellable_cancel (self->cancellable);
+      g_object_unref (self->cancellable);
     }
 
-  priv->cancellable = g_cancellable_new ();
-  printer_add_option_async (priv->printer_name,
-                            priv->option_name,
+  self->cancellable = g_cancellable_new ();
+  printer_add_option_async (self->printer_name,
+                            self->option_name,
                             values,
                             FALSE,
-                            priv->cancellable,
+                            self->cancellable,
                             printer_add_option_async_cb,
-                            widget);
+                            self);
 
   g_strfreev (values);
 }
 
 static gboolean
-construct_widget (PpPPDOptionWidget *widget)
+construct_widget (PpPPDOptionWidget *self)
 {
-  PpPPDOptionWidgetPrivate *priv = widget->priv;
   gint                      i;
 
   /* Don't show options which has only one choice */
-  if (priv->option && priv->option->num_choices > 1)
+  if (self->option && self->option->num_choices > 1)
     {
-      switch (priv->option->ui)
+      switch (self->option->ui)
         {
           case PPD_UI_BOOLEAN:
-              priv->switch_button = gtk_switch_new ();
-              g_signal_connect (priv->switch_button, "notify::active", G_CALLBACK (switch_changed_cb), widget);
-              gtk_box_pack_start (GTK_BOX (widget), priv->switch_button, FALSE, FALSE, 0);
+              self->switch_button = gtk_switch_new ();
+              g_signal_connect (self->switch_button, "notify::active", G_CALLBACK (switch_changed_cb), self);
+              gtk_box_pack_start (GTK_BOX (self), self->switch_button, FALSE, FALSE, 0);
               break;
 
           case PPD_UI_PICKONE:
-              priv->combo = combo_box_new ();
+              self->combo = combo_box_new ();
 
-              for (i = 0; i < priv->option->num_choices; i++)
+              for (i = 0; i < self->option->num_choices; i++)
                 {
-                  combo_box_append (priv->combo,
-                                    ppd_choice_translate (&priv->option->choices[i]),
-                                    priv->option->choices[i].choice);
+                  combo_box_append (self->combo,
+                                    ppd_choice_translate (&self->option->choices[i]),
+                                    self->option->choices[i].choice);
                 }
 
-              gtk_box_pack_start (GTK_BOX (widget), priv->combo, FALSE, FALSE, 0);
-              g_signal_connect (priv->combo, "changed", G_CALLBACK (combo_changed_cb), widget);
+              gtk_box_pack_start (GTK_BOX (self), self->combo, FALSE, FALSE, 0);
+              g_signal_connect (self->combo, "changed", G_CALLBACK (combo_changed_cb), self);
               break;
 
           case PPD_UI_PICKMANY:
-              priv->combo = combo_box_new ();
+              self->combo = combo_box_new ();
 
-              for (i = 0; i < priv->option->num_choices; i++)
+              for (i = 0; i < self->option->num_choices; i++)
                 {
-                  combo_box_append (priv->combo,
-                                    ppd_choice_translate (&priv->option->choices[i]),
-                                    priv->option->choices[i].choice);
+                  combo_box_append (self->combo,
+                                    ppd_choice_translate (&self->option->choices[i]),
+                                    self->option->choices[i].choice);
                 }
 
-              gtk_box_pack_start (GTK_BOX (widget), priv->combo, TRUE, TRUE, 0);
-              g_signal_connect (priv->combo, "changed", G_CALLBACK (combo_changed_cb), widget);
+              gtk_box_pack_start (GTK_BOX (self), self->combo, TRUE, TRUE, 0);
+              g_signal_connect (self->combo, "changed", G_CALLBACK (combo_changed_cb), self);
               break;
 
           default:
               break;
         }
 
-      priv->image = gtk_image_new_from_icon_name ("dialog-warning-symbolic", GTK_ICON_SIZE_MENU);
-      if (!priv->image)
-        priv->image = gtk_image_new_from_icon_name ("dialog-warning", GTK_ICON_SIZE_MENU);
-      gtk_box_pack_start (GTK_BOX (widget), priv->image, FALSE, FALSE, 0);
-      gtk_widget_set_no_show_all (GTK_WIDGET (priv->image), TRUE);
+      self->image = gtk_image_new_from_icon_name ("dialog-warning-symbolic", GTK_ICON_SIZE_MENU);
+      if (!self->image)
+        self->image = gtk_image_new_from_icon_name ("dialog-warning", GTK_ICON_SIZE_MENU);
+      gtk_box_pack_start (GTK_BOX (self), self->image, FALSE, FALSE, 0);
+      gtk_widget_set_no_show_all (GTK_WIDGET (self->image), TRUE);
 
       return TRUE;
     }
@@ -502,23 +463,21 @@ construct_widget (PpPPDOptionWidget *widget)
 }
 
 static void
-update_widget_real (PpPPDOptionWidget *widget)
+update_widget_real (PpPPDOptionWidget *self)
 {
-  PpPPDOptionWidgetPrivate *priv = widget->priv;
   ppd_option_t             *option = NULL, *iter;
   ppd_file_t               *ppd_file;
-  gchar                    *value = NULL;
   gint                      i;
 
-  if (priv->option)
+  if (self->option)
     {
-      option = cups_option_copy (priv->option);
-      cups_option_free (priv->option);
-      priv->option = NULL;
+      option = cups_option_copy (self->option);
+      cups_option_free (self->option);
+      self->option = NULL;
     }
-  else if (priv->ppd_filename)
+  else if (self->ppd_filename)
     {
-      ppd_file = ppdOpenFile (priv->ppd_filename);
+      ppd_file = ppdOpenFile (self->ppd_filename);
       ppdLocalize (ppd_file);
 
       if (ppd_file)
@@ -527,7 +486,7 @@ update_widget_real (PpPPDOptionWidget *widget)
 
           for (iter = ppdFirstOption(ppd_file); iter; iter = ppdNextOption(ppd_file))
             {
-              if (g_str_equal (iter->keyword, priv->option_name))
+              if (g_str_equal (iter->keyword, self->option_name))
                 {
                   option = cups_option_copy (iter);
                   break;
@@ -537,13 +496,15 @@ update_widget_real (PpPPDOptionWidget *widget)
           ppdClose (ppd_file);
         }
 
-      g_unlink (priv->ppd_filename);
-      g_free (priv->ppd_filename);
-      priv->ppd_filename = NULL;
+      g_unlink (self->ppd_filename);
+      g_free (self->ppd_filename);
+      self->ppd_filename = NULL;
     }
 
   if (option)
     {
+      g_autofree gchar *value = NULL;
+
       for (i = 0; i < option->num_choices; i++)
         if (option->choices[i].marked)
           value = g_strdup (option->choices[i].choice);
@@ -556,37 +517,35 @@ update_widget_real (PpPPDOptionWidget *widget)
           switch (option->ui)
             {
               case PPD_UI_BOOLEAN:
-                g_signal_handlers_block_by_func (priv->switch_button, switch_changed_cb, widget);
+                g_signal_handlers_block_by_func (self->switch_button, switch_changed_cb, self);
                 if (g_ascii_strcasecmp (value, "True") == 0)
-                  gtk_switch_set_active (GTK_SWITCH (priv->switch_button), TRUE);
+                  gtk_switch_set_active (GTK_SWITCH (self->switch_button), TRUE);
                 else
-                  gtk_switch_set_active (GTK_SWITCH (priv->switch_button), FALSE);
-                g_signal_handlers_unblock_by_func (priv->switch_button, switch_changed_cb, widget);
+                  gtk_switch_set_active (GTK_SWITCH (self->switch_button), FALSE);
+                g_signal_handlers_unblock_by_func (self->switch_button, switch_changed_cb, self);
                 break;
 
               case PPD_UI_PICKONE:
-                g_signal_handlers_block_by_func (priv->combo, combo_changed_cb, widget);
-                combo_box_set (priv->combo, value);
-                g_signal_handlers_unblock_by_func (priv->combo, combo_changed_cb, widget);
+                g_signal_handlers_block_by_func (self->combo, combo_changed_cb, self);
+                combo_box_set (self->combo, value);
+                g_signal_handlers_unblock_by_func (self->combo, combo_changed_cb, self);
                 break;
 
               case PPD_UI_PICKMANY:
-                g_signal_handlers_block_by_func (priv->combo, combo_changed_cb, widget);
-                combo_box_set (priv->combo, value);
-                g_signal_handlers_unblock_by_func (priv->combo, combo_changed_cb, widget);
+                g_signal_handlers_block_by_func (self->combo, combo_changed_cb, self);
+                combo_box_set (self->combo, value);
+                g_signal_handlers_unblock_by_func (self->combo, combo_changed_cb, self);
                 break;
 
               default:
                 break;
             }
-
-          g_free (value);
         }
 
       if (option->conflicted)
-        gtk_widget_show (priv->image);
+        gtk_widget_show (self->image);
       else
-        gtk_widget_hide (priv->image);
+        gtk_widget_hide (self->image);
     }
 
   cups_option_free (option);
@@ -596,18 +555,17 @@ static void
 get_named_dest_cb (cups_dest_t *dest,
                    gpointer     user_data)
 {
-  PpPPDOptionWidget        *widget = (PpPPDOptionWidget *) user_data;
-  PpPPDOptionWidgetPrivate *priv = widget->priv;
+  PpPPDOptionWidget *self = user_data;
 
-  if (priv->destination)
-    cupsFreeDests (1, priv->destination);
+  if (self->destination)
+    cupsFreeDests (1, self->destination);
 
-  priv->destination = dest;
-  priv->destination_set = TRUE;
+  self->destination = dest;
+  self->destination_set = TRUE;
 
-  if (priv->ppd_filename_set)
+  if (self->ppd_filename_set)
     {
-      update_widget_real (widget);
+      update_widget_real (self);
     }
 }
 
@@ -615,39 +573,36 @@ static void
 printer_get_ppd_cb (const gchar *ppd_filename,
                     gpointer     user_data)
 {
-  PpPPDOptionWidget        *widget = (PpPPDOptionWidget *) user_data;
-  PpPPDOptionWidgetPrivate *priv = widget->priv;
+  PpPPDOptionWidget *self = user_data;
 
-  if (priv->ppd_filename)
+  if (self->ppd_filename)
     {
-      g_unlink (priv->ppd_filename);
-      g_free (priv->ppd_filename);
+      g_unlink (self->ppd_filename);
+      g_free (self->ppd_filename);
     }
 
-  priv->ppd_filename = g_strdup (ppd_filename);
-  priv->ppd_filename_set = TRUE;
+  self->ppd_filename = g_strdup (ppd_filename);
+  self->ppd_filename_set = TRUE;
 
-  if (priv->destination_set)
+  if (self->destination_set)
     {
-      update_widget_real (widget);
+      update_widget_real (self);
     }
 }
 
 static void
-update_widget (PpPPDOptionWidget *widget)
+update_widget (PpPPDOptionWidget *self)
 {
-  PpPPDOptionWidgetPrivate *priv = widget->priv;
+  self->ppd_filename_set = FALSE;
+  self->destination_set = FALSE;
 
-  priv->ppd_filename_set = FALSE;
-  priv->destination_set = FALSE;
-
-  get_named_dest_async (priv->printer_name,
+  get_named_dest_async (self->printer_name,
                         get_named_dest_cb,
-                        widget);
+                        self);
 
-  printer_get_ppd_async (priv->printer_name,
+  printer_get_ppd_async (self->printer_name,
                          NULL,
                          0,
                          printer_get_ppd_cb,
-                         widget);
+                         self);
 }
