@@ -18,13 +18,17 @@
  * Author: Cosimo Cecchi <cosimoc@gnome.org>
  */
 
-#ifndef _CC_SEARCH_LOCATIONS_DIALOG_H
-#define _CC_SEARCH_LOCATIONS_DIALOG_H
+#pragma once
+
+#define HANDY_USE_UNSTABLE_API
+#include <handy.h>
+#undef HANDY_USE_UNSTABLE_API
 
 #include "cc-search-panel.h"
 
-GtkWidget *cc_search_locations_dialog_new (CcSearchPanel *panel);
+#define CC_SEARCH_LOCATIONS_DIALOG_TYPE (cc_search_locations_dialog_get_type ())
+G_DECLARE_FINAL_TYPE (CcSearchLocationsDialog, cc_search_locations_dialog, CC, SEARCH_LOCATIONS_DIALOG, HdyDialog)
 
-gboolean cc_search_locations_dialog_is_available (void);
+CcSearchLocationsDialog *cc_search_locations_dialog_new (CcSearchPanel *panel);
 
-#endif /* _CC_SEARCH_LOCATIONS_DIALOG_H */
+gboolean cc_search_locations_dialog_is_available        (void);
