@@ -560,7 +560,7 @@ cc_sharing_networks_class_init (CcSharingNetworksClass *klass)
                                                       G_PARAM_READABLE));
 
   gtk_widget_class_set_template_from_resource (widget_class,
-                                               "/org/gnome/control-center/sharing/networks.ui");
+                                               "/org/gnome/control-center/sharing/cc-sharing-networks.ui");
 
   gtk_widget_class_bind_template_child (widget_class, CcSharingNetworks, listbox);
 }
