@@ -2,11 +2,8 @@
 #include "config.h"
 
 #include <glib/gi18n.h>
-#include <clutter-gtk/clutter-gtk.h>
 
 #include "cc-wacom-page.h"
-#include "gsd-wacom-device.h"
-#include "clutter/clutter.h"
 
 #define FIXED_WIDTH 675
 
@@ -29,7 +26,7 @@ add_page (GList *devices,
 	  GtkWidget *notebook)
 {
 	GtkWidget *widget;
-	GsdWacomDevice *stylus, *eraser, *pad;
+	CcWacomDevice *stylus, *eraser, *pad;
 	GList *l;
 
 	if (devices == NULL)
@@ -37,20 +34,7 @@ add_page (GList *devices,
 
 	stylus = eraser = pad = NULL;
 	for (l = devices; l ; l = l->next) {
-		switch (gsd_wacom_device_get_device_type (l->data)) {
-		case WACOM_TYPE_ERASER:
-			eraser = l->data;
-			break;
-		case WACOM_TYPE_STYLUS:
-			stylus = l->data;
-			break;
-		case WACOM_TYPE_PAD:
-			pad = l->data;
-			break;
-		default:
-			/* Nothing */
-			;
-		}
+		stylus = l->data;
 	}
 	g_list_free (devices);
 
@@ -70,6 +54,66 @@ delete_event_cb (GtkWidget *widget,
 	return FALSE;
 }
 
+static GList *
+create_fake_cintiq (void)
+{
+	CcWacomDevice *device;
+	GList *devices;
+
+	device = cc_wacom_device_new_fake ("Wacom Cintiq 21UX2");
+	devices = g_list_prepend (NULL, device);
+
+	return devices;
+}
+
+static GList *
+create_fake_bt (void)
+{
+	CcWacomDevice *device;
+	GList *devices;
+
+	device = cc_wacom_device_new_fake ("Wacom Graphire Wireless");
+	devices = g_list_prepend (NULL, device);
+
+	return devices;
+}
+
+static GList *
+create_fake_x201 (void)
+{
+	CcWacomDevice *device;
+	GList *devices;
+
+	device = cc_wacom_device_new_fake ("Wacom Serial Tablet WACf004");
+	devices = g_list_prepend (NULL, device);
+
+	return devices;
+}
+
+static GList *
+create_fake_intuos4 (void)
+{
+	CcWacomDevice *device;
+	GList *devices;
+
+	device = cc_wacom_device_new_fake ("Wacom Intuos4 6x9");
+	devices = g_list_prepend (NULL, device);
+
+	return devices;
+}
+
+static GList *
+create_fake_h610pro (void)
+{
+	CcWacomDevice *device;
+	GList *devices;
+
+	device = cc_wacom_device_new_fake ("Huion H610 Pro");
+	devices = g_list_prepend (NULL, device);
+
+	return devices;
+}
+
 int main (int argc, char **argv)
 {
 	GtkWidget *window, *notebook;
@@ -79,14 +123,11 @@ int main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	if (gtk_clutter_init (&argc, &argv) != CLUTTER_INIT_SUCCESS) {
-		g_critical ("Unable to initialize Clutter");
-		return 1;
-        }
+	gtk_init (&argc, &argv);
 
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_resizable (GTK_WINDOW (window), FALSE);
-	gtk_widget_set_size_request (window, FIXED_WIDTH, -1);
+	gtk_window_set_default_size (GTK_WINDOW (window), FIXED_WIDTH, -1);
 	g_signal_connect (G_OBJECT (window), "delete-event",
 			  G_CALLBACK (delete_event_cb), NULL);
 	notebook = gtk_notebook_new ();
@@ -97,19 +138,19 @@ int main (int argc, char **argv)
 	gtk_container_add (GTK_CONTAINER (window), notebook);
 	gtk_widget_show (notebook);
 
-	devices = gsd_wacom_device_create_fake_intuos4 ();
+	devices = create_fake_intuos4 ();
 	add_page (devices, notebook);
 
-	devices = gsd_wacom_device_create_fake_cintiq ();
+	devices = create_fake_cintiq ();
 	add_page (devices, notebook);
 
-	devices = gsd_wacom_device_create_fake_bt ();
+	devices = create_fake_bt ();
 	add_page (devices, notebook);
 
-	devices = gsd_wacom_device_create_fake_x201 ();
+	devices = create_fake_x201 ();
 	add_page (devices, notebook);
 
-	devices = gsd_wacom_device_create_fake_h610pro ();
+	devices = create_fake_h610pro ();
 	add_page (devices, notebook);
 
 	gtk_widget_show (window);
