@@ -4,7 +4,8 @@
  * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#include <glib/gi18n.h>
+#include "config.h"
+#include <glib/gi18n-lib.h>
 
 #include "hdy-dialer-button.h"
 
@@ -104,7 +105,7 @@ hdy_dialer_button_get_property (GObject    *object,
 }
 
 /* This private method is prefixed by the call name because it will be a virtual
- * method in GTK+ 4.
+ * method in GTK 4.
  */
 static void
 hdy_dialer_button_measure (GtkWidget      *widget,
@@ -219,7 +220,7 @@ hdy_dialer_button_class_init (HdyDialerButtonClass *klass)
   g_object_class_install_properties (object_class, PROP_LAST_PROP, props);
 
   gtk_widget_class_set_template_from_resource (widget_class,
-                                               "/sm/puri/handy/dialer/ui/hdy-dialer-button.ui");
+                                               "/sm/puri/handy/ui/hdy-dialer-button.ui");
   gtk_widget_class_bind_template_child_private (widget_class, HdyDialerButton, label);
   gtk_widget_class_bind_template_child_private (widget_class, HdyDialerButton, secondary_label);
 }
